@@ -21,11 +21,11 @@ Netflow Parser supports currently only Netflow V9.
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =cut
 
-$Netflow::Parser::VERSION = '0.02';
+$Netflow::Parser::VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -223,7 +223,7 @@ sub _parse_v9 {
         my $flowset = substr($flowsets[$i + 1], 4);
         if ($flowset_id == 0) {
             if ($flowset) {
-                my @tmpl = $self->parse_template_v9($flowset);
+                my @tmpl = $self->_parse_template_v9($flowset);
                 if (@tmpl) {
                     $pp->add_template(@tmpl);
                 }
@@ -433,7 +433,7 @@ it under the same terms as Perl itself.
 
     sub add_template {
         my ($self, $tmpl) = @_;
-        push @{ $self->{template} }, $tmpl;
+        push @{ $self->{templates} }, $tmpl;
     }
 
     sub add_parsed {
